.. currentmodule:: obspy.io.quakeml
.. automodule:: obspy.io.quakeml

   .. comment to end block

   .. rubric:: Functions

   .. autosummary::
      :toctree: autogen
      :nosignatures:

      ~core._is_quakeml
      ~core._read_quakeml
      ~core._read_seishub_event_xml
      ~core._write_quakeml

   .. rubric:: Classes

   .. autosummary::
      :toctree: autogen
      :nosignatures:

      ~core.Pickler
      ~core.Unpickler
